@@ -37,8 +37,9 @@ class Message(object):
         self.prefix = prefix
         self.global_messages = messages
 
-        in_fd, self.messages_in  = tempfile.mkstemp(suffix='.cdist_message_in')
-        out_fd, self.messages_out = tempfile.mkstemp(suffix='.cdist_message_out')
+        in_fd, self.messages_in = tempfile.mkstemp(suffix='.cdist_message_in')
+        out_fd, self.messages_out = tempfile.mkstemp(
+                suffix='.cdist_message_out')
 
         os.close(in_fd)
         os.close(out_fd)
@@ -48,7 +49,7 @@ class Message(object):
     @property
     def env(self):
         env = {}
-        env['__messages_in']  = self.messages_in
+        env['__messages_in'] = self.messages_in
         env['__messages_out'] = self.messages_out
 
         return env
